#!/bin/sh
#-
# Copyright (c) 2013 Devin Teske <dteske@FreeBSD.org>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
############################################################ IDENT(1)
#
# $Title: fdpv proof-of-concept test-script $
# $FreeBSD$
#
############################################################ CONFIGURATION

LABEL_SIZE=28	# Width of labels
PBAR_SIZE=17	# Width of mini-progress bars

# Labels to display for each file-descriptor (required)
files="base.txz dict.txz doc.txz games.txz ports.txz"

############################################################ GLOBALS

# Defaults (overrides allowed)
: ${USE_COLOR=1} ${DIALOG:=dialog}

# Initial height/width of the dialog(1) widget
HEIGHT=$(( $( set -- $files; echo $# ) + 9 ))
WIDTH=$(( $LABEL_SIZE + $PBAR_SIZE + 9 ))

# Text to display before and after the mini-progress bar layout
prefix="Fetching distribution files...\n\n"
append="\n  Overall Progress:"

# Widths (in characters) of the above strings
PREFIX_WIDTH=30
APPEND_WIDTH=19

############################################################ INIT

#
# Initialize arguments (effects color)
#
if [ "$1" = "-X" ]; then
	DIALOG=Xdialog USE_XDIALOG=1 USE_COLOR=
	HEIGHT=$(( $HEIGHT + $HEIGHT / 4 ))
fi

# Make a custom version of the append string if we have color
if [ "$USE_COLOR" ]; then
	append="\n  \ZbOverall Progress:\Zn"
	APPEND_WIDTH=25
fi

############################################################ MAIN

#
# Is the calculated width less then our $prefix/$append widths?
#
[ $WIDTH -lt $PREFIX_WIDTH ] && WIDTH=$(( $PREFIX_WIDTH + 4 ))
[ $WIDTH -lt $APPEND_WIDTH ] && WIDTH=$(( $APPEND_WIDTH + 4 ))

#
# Debugging desired? (send dialog(1) data to standard output when given `-d')
#
if [ "$1" = "-d" ]; then
	shift 1
	./fdpv -L $LABEL_SIZE -P $PBAR_SIZE -p "$prefix" -a "$append" "$@" \
		$files
else
	./fdpv -L $LABEL_SIZE -P $PBAR_SIZE -p "$prefix" -a "$append" "$@" \
		$files |
		env ${USE_XDIALOG:+XDIALOG_HIGH_DIALOG_COMPAT=1} $DIALOG \
			--title "Distributions" \
			--backtitle "bsdconfig distributions" \
			${USE_COLOR:+--colors} ${USE_XDIALOG:+--left} \
			--gauge "" $HEIGHT $WIDTH
fi

################################################################################
# END
################################################################################
